Author: philip
Date: Tue Mar 16 17:57:31 2010
New Revision: 923905

URL: http://svn.apache.org/viewvc?rev=923905&view=rev
Log:
* subversion/libsvn_client/repos_diff.c
  (struct edit_baton, get_dir_abspath, get_parent_dir_abspath): Tweak
   comments, no code changes.

Suggested by: gstein

Modified:
    subversion/trunk/subversion/libsvn_client/repos_diff.c

Modified: subversion/trunk/subversion/libsvn_client/repos_diff.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/repos_diff.c?rev=923905&r1=923904&r2=923905&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/repos_diff.c (original)
+++ subversion/trunk/subversion/libsvn_client/repos_diff.c Tue Mar 16 17:57:31 
2010
@@ -50,7 +50,8 @@ struct edit_baton {
      URL open in RA_SESSION below. */
   const char *target;
 
-  /* ADM_ACCESS is an access baton that includes the TARGET directory */
+  /* A working copy context for TARGET, NULL if this is purely a
+     repository operation. */
   svn_wc_context_t *wc_ctx;
 
   /* The callback and calback argument that implement the file comparison
@@ -321,12 +322,12 @@ get_dirprops_from_ra(struct dir_baton *b
 }
 
 
-/* Return in *LOCAL_DIR_ABSPATH the absolute path for the directory
-   PATH if PATH is a versioned directory.  If PATH is not a versioned
+/* If WC_CTX is NULL then set *LOCAL_DIR_ABSPATH to NULL otherwise
+   return in *LOCAL_DIR_ABSPATH the absolute path for the directory
+   PATH if PATH is a versioned directory. If PATH is not a versioned
    directory and LENIENT is FALSE then return an error
-   SVN_ERR_WC_NOT_WORKING_COPY.  If LENIENT is TRUE then failure to
-   find an access baton will not return an error but will set
-   *LOCAL_DIR_ABSPATH to NULL instead.
+   SVN_ERR_WC_NOT_WORKING_COPY.  If LENIENT is TRUE then no error will
+   be returned but instead *LOCAL_DIR_ABSPATH will be set to NULL.
 
    This rather odd interface was originally designed around searching
    an access baton set. */
@@ -367,7 +368,7 @@ get_dir_abspath(const char **local_dir_a
 
 /* Like get_path_access except the returned path, in
    *LOCAL_PARENT_DIR_ABSPATH, is for the parent of PATH rather than
-   for PATH itself. */
+   for PATH itself.  As for get_path_access WC_CTX may be NULL. */
 static svn_error_t *
 get_parent_dir_abspath(const char **local_parent_dir_abspath,
                        svn_wc_context_t *wc_ctx,


Reply via email to